@@ -1,4 +1,4 @@
-# $Id: twitter.py 1036 2014-09-21 15:23:03Z mwall $
+# $Id: twitter.py 1040 2014-09-22 15:09:28Z mwall $
 # Copyright 2014 Matthew Wall
 """
 Tweet weather data
@@ -17,7 +17,7 @@ Installation:
     [[Twitter]]
         station = STATION_IDENTIFIER
         app_key = APP_KEY
-        app_secret = APP_SECRET
+        app_key_secret = APP_KEY_SECRET
         oauth_token = OAUTH_TOKEN
         oauth_token_secret = OAUTH_TOKEN_SECRET
 
@@ -33,13 +33,14 @@ Installation:
 import Queue
 import sys
 import syslog
+import time
 
 import weewx
 import weewx.restx
 
 from twython import Twython, TwythonError, TwythonAuthError, TwythonRateLimitError
 
-VERSION = "0.1"
+VERSION = "0.2"
 
 def logmsg(level, msg):
     syslog.syslog(level, 'restx: Twitter: %s' % msg)
@@ -53,6 +54,10 @@ def loginf(msg):
 def logerr(msg):
     logmsg(syslog.LOG_ERR, msg)
 
+def _format(label, fmt, datum):
+    s = fmt % datum if datum is not None else "None"
+    return "%s: %s" % (label, s)
+
 class Twitter(weewx.restx.StdRESTbase):
     def __init__(self, engine, config_dict):
         super(Twitter, self).__init__(engine, config_dict)
@@ -86,6 +91,18 @@ class Twitter(weewx.restx.StdRESTbase):
         self.loop_queue.put(event.record)
 
 class TwitterThread(weewx.restx.RESTThread):
+    _FORMATS = {
+        "barometer":   ["P",  "%.3f"],
+        "inTemp":      ["iT", "%.2f"],
+        "outTemp":     ["oT", "%.2f"],
+        "inHumidity":  ["iH", "%.2f"],
+        "outHumidity": ["oH", "%.2f"],
+        "windSpeed":   ["Ws", "%.1f"],
+        "windGust":    ["Wg", "%.1f"],
+        "windDir":     ["Wd", "%.0f"],
+        "rain":        ["R",  "%.3f"],
+        }
+
     def __init__(self, queue, 
                  station,
                  app_key, app_key_secret, oauth_token, oauth_token_secret,
@@ -110,26 +127,25 @@ class TwitterThread(weewx.restx.RESTThread):
         self.oauth_token_secret = oauth_token_secret
 
     def process_record(self, record, dummy_archive):
-        wstr = "%s: ts: %s; P: %s; iT: %s; oT: %s; iH: %s; oH: %s; Ws: %s; Wg: %s; Wd: %s; R: %s" % (
-            self.station,
-            record['dateTime'],
-            record['barometer'],
-            record['inTemp'], record['outTemp'],
-            record['inHumidity'], record['outHumidity'],
-            record['windSpeed'], record['windGust'], record['windDir'],
-            record['rain'])
+        s = []
+        s.append("%s: ts: %s" % (self.station, record['dateTime']))
+        for obs in self._FORMATS:
+            if obs in record:
+                s.append(_format(self._FORMATS[obs][0], self._FORMATS[obs][1],
+                                 record[obs]))
+        wstr = '; '.join(s)
         ntries = 0
         while ntries < self.max_tries:
             ntries += 1
-            twitter = Twython(self.app_key, self.app_secret,
-                              self.oauth_token, self.oauth_token_secret)
-            twitter.update_status(status=wstr)
+            try:
+                twitter = Twython(self.app_key, self.app_key_secret,
+                                  self.oauth_token, self.oauth_token_secret)
+                twitter.update_status(status=wstr)
             except (TwythonError, TwythonAuthError, TwythonRateLimitError), e:
                 logerr("Failed attempt %d of %d to tweet: %s" %
                        (ntries, self.max_tries, e))
                 logdbg("Waiting %d seconds before retry" % self.retry_wait)
                 time.sleep(self.retry_wait)
         else:
-            msg = "Max retries (%d) exceeded for tweeting" % self.max_tries
-            logerr(msg)
-
+            raise weewx.restx.FailedPost("Max retries (%d) exceeded" %
+                                         self.max_tries)
